@@ -1,9 +1,12 @@
 #!/bin/sh
-mkdir -p tmp/test-save
+mkdir -p tmp/test-save/bin
+RUNDIR="$PWD"
+trap 'rm -rf "$RUNDIR/tmp"' EXIT
+
 cp test/data/test-save-package.json tmp/test-save/package.json
 
 cd tmp/test-save || exit
-../../clib-install -c --no-save stephenmathieson/tabs-to-spaces@1.0.0 >/dev/null
+../../clib-install -c --no-save stephenmathieson/tabs-to-spaces@1.0.0 -P . >/dev/null
 ../../clib-install -c -N darthtrevino/str-concat@0.0.2 >/dev/null
 ../../clib-install -c --dev --no-save jwerle/fs.c@0.1.1 >/dev/null
 ../../clib-install -c -d --no-save clibs/parson@1.0.2 >/dev/null
